# PyChance
An unofficial implementation of the Perchance.org text generation engine. Support is planned for most of their features, with the exception of the ability to embed actual javascript in the strings.
